@@ -16,9 +16,19 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: cycles.h,v 1.2 2004/03/25 19:31:43 joq Exp $
+    $Id: cycles.h 948 2006-05-15 17:12:44Z pbd $
 */
 
-/* the i486 version of this header is compatible */
+#ifndef __jack_cycles_h__
+#define __jack_cycles_h__
 
-#include <config/cpu/i486/cycles.h>
+typedef unsigned long long cycles_t;
+
+static inline cycles_t get_cycles (void)
+{
+	unsigned long long ret;
+	__asm__ __volatile__("rdtsc" : "=A" (ret));
+	return ret;
+}
+
+#endif /* __jack_cycles_h__ */
