@@ -15,38 +15,21 @@
     along with this program; if not, write to the Free Software 
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: time.h,v 1.2 2004/03/25 19:31:44 joq Exp $
+    $Id: time.h 948 2006-05-15 17:12:44Z pbd $
 */
 
 #ifndef __jack_time_h__
 #define __jack_time_h__
 
-/*
- *  This is the MacOSX version of <jack/time.h>.  It overrides the
- *  generic version via the configure.hosts mechanism.
- */
 #include <jack/types.h>
 #include <mach/mach_time.h>
 
-/* This is a kludge.  We need one global instantiation of this
- * variable in each address space.  So, libjack/client.c declares the
- * actual storage.  Other source files will see it as an extern. */
-#define JACK_TIME_GLOBAL_DECL double __jack_time_ratio
-extern JACK_TIME_GLOBAL_DECL;
+extern double __jack_time_ratio;
 
 static inline jack_time_t 
 jack_get_microseconds(void) 
 {  
-        return  mach_absolute_time () * __jack_time_ratio;
-}
-
-/* This should only be called ONCE per process. */
-static inline void 
-jack_init_time ()
-{
-        mach_timebase_info_data_t info; 
-        mach_timebase_info(&info);
-        __jack_time_ratio = ((float)info.numer/info.denom) / 1000;
+        return  (jack_time_t) mach_absolute_time () * __jack_time_ratio;
 }
 
 #endif /* __jack_time_h__ */
