@@ -7,6 +7,7 @@
 #include <config.h>
 
 #include <jack/jack.h>
+#include <jack/port.h>
 
 char * my_name;
 
@@ -25,9 +26,11 @@ show_usage (void)
 	fprintf (stderr, "List active Jack ports, and optionally display extra information.\n\n");
 	fprintf (stderr, "Display options:\n");
 	fprintf (stderr, "        -c, --connections     List connections to/from each port\n");
-	fprintf (stderr, "        -l, --latency         Display total latency in frames at each port\n");
+	fprintf (stderr, "        -l, --latency         Display per-port latency in frames at each port\n");
+	fprintf (stderr, "        -L, --latency         Display total latency in frames at each port\n");
 	fprintf (stderr, "        -p, --properties      Display port properties. Output may include:\n"
 			 "                              input|output, can-monitor, physical, terminal\n\n");
+	fprintf (stderr, "        -t, --type            Display port type\n");
 	fprintf (stderr, "        -h, --help            Display this help message\n");
 	fprintf (stderr, "        --version             Output version information and exit\n\n");
 	fprintf (stderr, "For more information see http://jackit.sourceforge.net/\n");
@@ -41,15 +44,19 @@ main (int argc, char *argv[])
 	const char **ports, **connections;
 	unsigned int i, j;
 	int show_con = 0;
-	int show_latency = 0;
+	int show_port_latency = 0;
+	int show_total_latency = 0;
 	int show_properties = 0;
+	int show_type = 0;
 	int c;
 	int option_index;
 
 	struct option long_options[] = {
 		{ "connections", 0, 0, 'c' },
-		{ "latency", 0, 0, 'l' },
+		{ "port-latency", 0, 0, 'l' },
+		{ "total-latency", 0, 0, 'L' },
 		{ "properties", 0, 0, 'p' },
+		{ "type", 0, 0, 't' },
 		{ "help", 0, 0, 'h' },
 		{ "version", 0, 0, 'v' },
 		{ 0, 0, 0, 0 }
@@ -62,17 +69,23 @@ main (int argc, char *argv[])
 		my_name ++;
 	}
 
-	while ((c = getopt_long (argc, argv, "clphv", long_options, &option_index)) >= 0) {
+	while ((c = getopt_long (argc, argv, "clLphvt", long_options, &option_index)) >= 0) {
 		switch (c) {
 		case 'c':
 			show_con = 1;
 			break;
 		case 'l':
-			show_latency = 1;
+			show_port_latency = 1;
+			break;
+		case 'L':
+			show_total_latency = 1;
 			break;
 		case 'p':
 			show_properties = 1;
 			break;
+		case 't':
+			show_type = 1;
+			break;
 		case 'h':
 			show_usage ();
 			return 1;
@@ -108,6 +121,9 @@ main (int argc, char *argv[])
 
 	for (i = 0; ports[i]; ++i) {
 		printf ("%s\n", ports[i]);
+
+		jack_port_t *port = jack_port_by_name (client, ports[i]);
+
 		if (show_con) {
 			if ((connections = jack_port_get_all_connections (client, jack_port_by_name(client, ports[i]))) != 0) {
 				for (j = 0; connections[j]; j++) {
@@ -116,16 +132,19 @@ main (int argc, char *argv[])
 				free (connections);
 			} 
 		}
-		if (show_latency) {
-			jack_port_t *port = jack_port_by_name (client, ports[i]);
+		if (show_port_latency) {
 			if (port) {
-				printf ("	latency = %" PRIu32 " frames\n",
+				printf ("	port latency = %" PRIu32 " frames\n",
+					jack_port_get_latency (port));
+			}
+		}
+		if (show_total_latency) {
+			if (port) {
+				printf ("	total latency = %" PRIu32 " frames\n",
 					jack_port_get_total_latency (client, port));
-				free (port);
 			}
 		}
 		if (show_properties) {
-			jack_port_t *port = jack_port_by_name (client, ports[i]);
 			if (port) {
 				int flags = jack_port_flags (port);
 				printf ("	properties: ");
@@ -147,6 +166,13 @@ main (int argc, char *argv[])
 				putc ('\n', stdout);
 			}
 		}
+		if (show_type) {
+			if (port) {
+				putc ('\t', stdout);
+				fputs (port->type_info->type_name, stdout);
+				putc ('\n', stdout);
+			}
+		}
 	}
 	jack_client_close (client);
 	exit (0);
