@@ -15,7 +15,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: thread.h,v 1.5 2005/04/15 21:27:15 pbd Exp $
+    $Id: thread.h 948 2006-05-15 17:12:44Z pbd $
 */
 
 #ifndef __jack_thread_h__
@@ -27,6 +27,10 @@ extern "C" {
 
 #include <pthread.h>
 
+/* use 512KB stack per thread - the default is way too high to be feasible 
+ * with mlockall() on many systems */
+#define THREAD_STACK 524288
+       
 /** @file thread.h
  *
  * Library functions to standardize thread creation for JACK and its
