@@ -19,7 +19,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  *
- *  $Id: clientengine.c,v 1.11 2004/12/27 02:05:30 joq Exp $
+ *  $Id: clientengine.c 985 2006-08-29 15:21:17Z paul $
  */
 
 #include <config.h>
@@ -435,12 +435,7 @@ jack_setup_client_control (jack_engine_t *engine, int fd,
 
 	} else {
 
-		char shm_name[PATH_MAX+1];
-
-                snprintf (shm_name, sizeof (shm_name), "jack-c-%s", name);
-                
-                if (jack_shmalloc (shm_name,
-				   sizeof (jack_client_control_t), 
+                if (jack_shmalloc (sizeof (jack_client_control_t), 
 				   &client->control_shm)) {
                         jack_error ("cannot create client control block for %s",
 				    name);
@@ -665,7 +660,7 @@ jack_client_create (jack_engine_t *engine, int client_fd)
 
 		/* JACK protocol incompatibility */
 		res.status |= (JackFailure|JackVersionError);
-		jack_error ("JACK protocol mismatch");
+		jack_error ("JACK protocol mismatch (%d vs %d)", req.protocol_v, jack_protocol_version);
 		if (write (client_fd, &res, sizeof (res)) != sizeof (res)) {
 			jack_error ("cannot write client connection response");
 		}
