@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: engine.c,v 1.126 2005/06/15 09:18:40 rncbc Exp $
+    $Id: engine.c 979 2006-06-26 15:11:44Z joq $
 */
 
 #include <config.h>
@@ -78,6 +78,8 @@ typedef struct _jack_driver_info {
     dlhandle       handle;
 } jack_driver_info_t;
 
+jack_timer_type_t clock_source = JACK_TIMER_SYSTEM_CLOCK;
+
 static int                    jack_port_assign_buffer (jack_engine_t *,
 						       jack_port_internal_t *);
 static jack_port_internal_t *jack_get_port_by_name (jack_engine_t *,
@@ -198,6 +200,7 @@ static int
 make_socket_subdirectories (const char *server_name)
 {
 	struct stat statbuf;
+        char server_dir[PATH_MAX+1] = "";
 
 	/* check tmpdir directory */
 	if (stat (jack_tmpdir, &statbuf)) {
@@ -218,7 +221,7 @@ make_socket_subdirectories (const char *server_name)
 	}
 
 	/* create server_name subdirectory */
-	if (make_directory (jack_server_dir (server_name)) < 0) {
+	if (make_directory (jack_server_dir (server_name, server_dir)) < 0) {
 		return -1;
 	}
 
@@ -230,6 +233,7 @@ make_sockets (const char *server_name, int fd[2])
 {
 	struct sockaddr_un addr;
 	int i;
+        char server_dir[PATH_MAX+1] = "";
 
 	if (make_socket_subdirectories (server_name) < 0) {
 		return -1;
@@ -246,7 +250,7 @@ make_sockets (const char *server_name, int fd[2])
 	addr.sun_family = AF_UNIX;
 	for (i = 0; i < 999; i++) {
 		snprintf (addr.sun_path, sizeof (addr.sun_path) - 1,
-			  "%s/jack_%d", jack_server_dir (server_name), i);
+			  "%s/jack_%d", jack_server_dir (server_name, server_dir), i);
 		if (access (addr.sun_path, F_OK) != 0) {
 			break;
 		}
@@ -284,7 +288,7 @@ make_sockets (const char *server_name, int fd[2])
 	addr.sun_family = AF_UNIX;
 	for (i = 0; i < 999; i++) {
 		snprintf (addr.sun_path, sizeof (addr.sun_path) - 1,
-			  "%s/jack_ack_%d", jack_server_dir (server_name), i);
+			  "%s/jack_ack_%d", jack_server_dir (server_name, server_dir), i);
 		if (access (addr.sun_path, F_OK) != 0) {
 			break;
 		}
@@ -415,23 +419,17 @@ jack_resize_port_segment (jack_engine_t *engine,
 
 	if (shm_info->attached_at == 0) {
 
-		char name[64];
-
-		/* no segment allocated, yet */
-		snprintf (name, sizeof(name), "jck-[%s]",
-			  port_type->type_name);
-
-		if (jack_shmalloc (name, size, shm_info)) {
+		if (jack_shmalloc (size, shm_info)) {
 			jack_error ("cannot create new port segment of %d"
-				    " bytes, name = %s (%s)", 
-				    size, name,
+				    " bytes (%s)", 
+				    size,
 				    strerror (errno));
 			return;
 		}
 		
 		if (jack_attach_shm (shm_info)) {
 			jack_error ("cannot attach to new port segment "
-				    "(name=%s) (%s)", name, strerror (errno));
+				    "(%s)", strerror (errno));
 			return;
 		}
 
@@ -620,7 +618,7 @@ static JSList *
 jack_process_external(jack_engine_t *engine, JSList *node)
 {
 	int status = 0;
-	char c;
+	char c = 0;
 	struct pollfd pfd[1];
 	int poll_timeout;
 	jack_client_internal_t *client;
@@ -901,7 +899,7 @@ jack_watchdog_thread (void *arg)
 	engine->watchdog_check = 0;
 
 	while (1) {
-		sleep (5);
+		usleep (1000 * JACKD_WATCHDOG_TIMEOUT);
 		if (!engine->freewheeling && engine->watchdog_check == 0) {
 
 			jack_error ("jackd watchdog: timeout - killing jackd");
@@ -909,7 +907,7 @@ jack_watchdog_thread (void *arg)
 			/* Kill the current client (guilt by association). */
 			if (engine->current_client) {
 					kill (engine->current_client->
-					      control->pgrp, SIGKILL);
+					      control->pid, SIGKILL);
 			}
 
 			/* kill our process group, try to get a dump */
@@ -1533,16 +1531,41 @@ jack_engine_t *
 jack_engine_new (int realtime, int rtpriority, int do_mlock, int do_unlock,
 		 const char *server_name, int temporary, int verbose,
 		 int client_timeout, unsigned int port_max, pid_t wait_pid,
-		 JSList *drivers)
+		 jack_nframes_t frame_time_offset, JSList *drivers)
 {
 	jack_engine_t *engine;
 	unsigned int i;
+        char server_dir[PATH_MAX+1] = "";
 
 #ifdef USE_CAPABILITIES
 	uid_t uid = getuid ();
 	uid_t euid = geteuid ();
 #endif /* USE_CAPABILITIES */
 
+	/* before we start allocating resources, make sure that if realtime was requested that we can 
+	   actually do it.
+	*/
+
+	if (realtime) {
+		if (jack_acquire_real_time_scheduling (pthread_self(), 10) != 0) {
+			/* can't run realtime - time to bomb */
+			return NULL;
+		}
+
+		jack_drop_real_time_scheduling (pthread_self());
+
+#ifdef USE_MLOCK
+
+		if (do_mlock && (mlockall (MCL_CURRENT | MCL_FUTURE) != 0)) {
+			jack_error ("cannot lock down memory for jackd (%s)",
+				    strerror (errno));
+#ifdef ENSURE_MLOCK
+			return NULL;
+#endif /* ENSURE_MLOCK */
+		}
+#endif /* USE_MLOCK */
+	}
+
 	/* start a thread to display messages from realtime threads */
 	jack_messagebuffer_init();
 
@@ -1598,8 +1621,7 @@ jack_engine_new (int realtime, int rtpriority, int do_mlock, int do_unlock,
 
 	srandom (time ((time_t *) 0));
 
-	if (jack_shmalloc ("jack-engine",
-			   sizeof (jack_control_t)
+	if (jack_shmalloc (sizeof (jack_control_t)
 			   + ((sizeof (jack_port_shared_t) * engine->port_max)),
 			   &engine->control_shm)) {
 		jack_error ("cannot create engine control shared memory "
@@ -1679,7 +1701,12 @@ jack_engine_new (int realtime, int rtpriority, int do_mlock, int do_unlock,
 	engine->control->xrun_delayed_usecs = 0;
 	engine->control->max_delayed_usecs = 0;
 
-	engine->control->frame_timer.frames = 0;
+	jack_set_clock_source (clock_source);
+	engine->control->clock_source = clock_source;
+
+	VERBOSE (engine, "clock source = %s\n", jack_clock_source_name (clock_source));
+
+	engine->control->frame_timer.frames = frame_time_offset;
 	engine->control->frame_timer.reset_pending = 0;
 	engine->control->frame_timer.current_wakeup = 0;
 	engine->control->frame_timer.next_wakeup = 0;
@@ -1730,22 +1757,11 @@ jack_engine_new (int realtime, int rtpriority, int do_mlock, int do_unlock,
 	}
 #endif /* USE_CAPABILITIES */
 
-#ifdef USE_MLOCK
-
-        if (realtime && do_mlock && (mlockall (MCL_CURRENT | MCL_FUTURE) != 0)) {
-		jack_error ("cannot lock down memory for jackd (%s)",
-			    strerror (errno));
-#ifdef ENSURE_MLOCK
-		return NULL;
-#endif /* ENSURE_MLOCK */
-        }
-#endif /* USE_MLOCK */
-
 	engine->control->engine_ok = 1;
 
 	snprintf (engine->fifo_prefix, sizeof (engine->fifo_prefix),
 		  "%s/jack-ack-fifo-%d",
-		  jack_server_dir (engine->server_name), getpid ());
+		  jack_server_dir (engine->server_name, server_dir), getpid ());
 
 	(void) jack_get_fifo_fd (engine, 0);
 
@@ -2490,6 +2506,17 @@ jack_get_port_total_latency (jack_engine_t *engine,
 	jack_nframes_t latency;
 	jack_nframes_t max_latency = 0;
 
+#ifdef DEBUG_TOTAL_LATENCY_COMPUTATION
+	char prefix[32];
+	int i;
+
+	for (i = 0; i < hop_count; ++i) {
+		prefix[i] = '\t';
+	}
+
+	prefix[i] = '\0';
+#endif
+
 	/* call tree must hold engine->client_lock. */
 
 	latency = port->shared->latency;
@@ -2502,6 +2529,10 @@ jack_get_port_total_latency (jack_engine_t *engine,
 		return latency;
 	}
 
+#ifdef DEBUG_TOTAL_LATENCY_COMPUTATION
+	fprintf (stderr, "\n%sFor port %s (%s)\n", prefix, port->shared->name, (toward_port ? "toward" : "away"));
+#endif
+	
 	for (node = port->connections; node; node = jack_slist_next (node)) {
 
 		jack_nframes_t this_latency;
@@ -2514,12 +2545,27 @@ jack_get_port_total_latency (jack_engine_t *engine,
 		     (connection->source->shared == port->shared)) ||
 		    (!toward_port &&
 		     (connection->destination->shared == port->shared))) {
+
+#ifdef DEBUG_TOTAL_LATENCY_COMPUTATION
+			fprintf (stderr, "%s\tskip connection %s->%s\n",
+				 prefix,
+				 connection->source->shared->name,
+				 connection->destination->shared->name);
+#endif
+
 			continue;
 		}
 
+#ifdef DEBUG_TOTAL_LATENCY_COMPUTATION
+		fprintf (stderr, "%s\tconnection %s->%s ... ", 
+			 prefix,
+			 connection->source->shared->name,
+			 connection->destination->shared->name);
+#endif
 		/* if we're a destination in the connection, recurse
 		   on the source to get its total latency
 		*/
+
 		if (connection->destination == port) {
 
 			if (connection->source->shared->flags
@@ -2557,6 +2603,10 @@ jack_get_port_total_latency (jack_engine_t *engine,
 		}
 	}
 
+#ifdef DEBUG_TOTAL_LATENCY_COMPUTATION
+	fprintf (stderr, "%s\treturn %lu + %lu = %lu\n", prefix, latency, max_latency, latency + max_latency);
+#endif	
+
 	return latency + max_latency;
 }
 
