@@ -16,12 +16,13 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 
-    $Id: jackd.c,v 1.53 2005/06/15 09:18:40 rncbc Exp $
+    $Id: jackd.c 978 2006-06-20 22:15:52Z joq $
 */
 
 #include <config.h>
 
 #include <stdio.h>
+#include <ctype.h>
 #include <signal.h>
 #include <getopt.h>
 #include <sys/types.h>
@@ -62,8 +63,9 @@ static int do_mlock = 1;
 static int temporary = 0;
 static int verbose = 0;
 static int client_timeout = 0; /* msecs; if zero, use period size. */
-static unsigned int port_max = 128;
+static unsigned int port_max = 256;
 static int do_unlock = 0;
+static jack_nframes_t frame_time_offset = 0;
 
 static void 
 do_nothing_handler (int sig)
@@ -144,7 +146,7 @@ jack_main (jack_driver_desc_t * driver_desc, JSList * driver_params)
 	if ((engine = jack_engine_new (realtime, realtime_priority, 
 				       do_mlock, do_unlock, server_name,
 				       temporary, verbose, client_timeout,
-				       port_max, getpid(), drivers)) == 0) {
+				       port_max, getpid(), frame_time_offset, drivers)) == 0) {
 		fprintf (stderr, "cannot create engine\n");
 		return -1;
 	}
@@ -281,7 +283,7 @@ jack_drivers_get_descriptor (JSList * drivers, const char * sofile)
 		}
 	}
 
-	strncpy (descriptor->file, filename, PATH_MAX);
+	snprintf (descriptor->file, sizeof(descriptor->file), "%s", filename);
 	free (filename);
 
 	return descriptor;
@@ -365,14 +367,16 @@ static void usage (FILE *file)
 "             [ --unlock OR -u ]\n"
 "             [ --timeout OR -t client-timeout-in-msecs ]\n"
 "             [ --port-max OR -p maximum-number-of-ports]\n"
+"             [ --debug-timer OR -D ]\n"
 "             [ --verbose OR -v ]\n"
+"             [ --clocksource OR -c [ c(ycle) | h(pet) | s(ystem) ]\n"
 "             [ --silent OR -s ]\n"
 "             [ --version OR -V ]\n"
-"         -d driver [ ... driver args ... ]\n"
-"             where driver can be `alsa', `coreaudio', `dummy',\n"
-"                                 `oss' or `portaudio'\n\n"
-"       jackd -d driver --help\n"
-"             to display options for each driver\n\n");
+"         -d backend [ ... backend args ... ]\n"
+"             The backend can be `alsa', `coreaudio', `dummy',\n"
+"                                `freebob', `oss' or `portaudio'.\n\n"
+"       jackd -d backend --help\n"
+"             to display options for each backend\n\n");
 }	
 
 static jack_driver_desc_t *
@@ -399,7 +403,8 @@ jack_cleanup_files (const char *server_name)
 {
 	DIR *dir;
 	struct dirent *dirent;
-	char *dir_name = jack_server_dir (server_name);
+	char dir_name[PATH_MAX+1] = "";
+        jack_server_dir (server_name, dir_name);
 
 	/* On termination, we remove all files that jackd creates so
 	 * subsequent attempts to start jackd will not believe that an
@@ -425,7 +430,7 @@ jack_cleanup_files (const char *server_name)
 	/* unlink all the files in this directory, they are mine */
 	while ((dirent = readdir (dir)) != NULL) {
 
-		char fullpath[PATH_MAX];
+		char fullpath[PATH_MAX+1];
 
 		if ((strcmp (dirent->d_name, ".") == 0)
 		    || (strcmp (dirent->d_name, "..") == 0)) {
@@ -458,46 +463,11 @@ jack_cleanup_files (const char *server_name)
 	}
 }
 
-int	       
-main (int argc, char *argv[])
-
+static void
+maybe_use_capabilities ()
 {
-	jack_driver_desc_t * desc;
-	const char *options = "-ad:P:uvshVRTFl:t:mn:p:";
-	struct option long_options[] = 
-	{ 
-		{ "driver", 1, 0, 'd' },
-		{ "verbose", 0, 0, 'v' },
-		{ "help", 0, 0, 'h' },
-		{ "port-max", 1, 0, 'p' },
-		{ "no-mlock", 0, 0, 'm' },
-		{ "name", 0, 0, 'n' },
-		{ "unlock", 0, 0, 'u' },
-		{ "realtime", 0, 0, 'R' },
-		{ "realtime-priority", 1, 0, 'P' },
-		{ "timeout", 1, 0, 't' },
-		{ "temporary", 0, 0, 'T' },
-		{ "version", 0, 0, 'V' },
-		{ "silent", 0, 0, 's' },
-		{ 0, 0, 0, 0 }
-	};
-	int opt = 0;
-	int option_index = 0;
-	int seen_driver = 0;
-	char *driver_name = NULL;
-	char **driver_args = NULL;
-	JSList * driver_params;
-	int driver_nargs = 1;
-	int show_version = 0;
-	int i;
-	int rc;
 #ifdef USE_CAPABILITIES
 	int status;
-#endif
-
-	setvbuf (stdout, NULL, _IOLBF, 0);
-
-#ifdef USE_CAPABILITIES
 
 	/* check to see if there is a pipe in the right descriptor */
 	if ((status = fstat (PIPE_WRITE_FD, &pipe_stat)) == 0 &&
@@ -530,6 +500,46 @@ main (int argc, char *argv[])
 		}
 	}
 #endif /* USE_CAPABILITIES */
+}
+
+int	       
+main (int argc, char *argv[])
+
+{
+	jack_driver_desc_t * desc;
+	const char *options = "-ad:P:uvshVRTFl:t:mn:p:c:";
+	struct option long_options[] = 
+	{ 
+		{ "driver", 1, 0, 'd' },
+		{ "verbose", 0, 0, 'v' },
+		{ "help", 0, 0, 'h' },
+		{ "port-max", 1, 0, 'p' },
+		{ "no-mlock", 0, 0, 'm' },
+		{ "name", 1, 0, 'n' },
+		{ "unlock", 0, 0, 'u' },
+		{ "realtime", 0, 0, 'R' },
+		{ "realtime-priority", 1, 0, 'P' },
+		{ "timeout", 1, 0, 't' },
+		{ "temporary", 0, 0, 'T' },
+		{ "version", 0, 0, 'V' },
+		{ "silent", 0, 0, 's' },
+		{ "clock-source", 1, 0, 'c' },
+		{ 0, 0, 0, 0 }
+	};
+	int opt = 0;
+	int option_index = 0;
+	int seen_driver = 0;
+	char *driver_name = NULL;
+	char **driver_args = NULL;
+	JSList * driver_params;
+	int driver_nargs = 1;
+	int show_version = 0;
+	int i;
+	int rc;
+
+	setvbuf (stdout, NULL, _IOLBF, 0);
+
+	maybe_use_capabilities ();
 
 	opterr = 0;
 	while (!seen_driver &&
@@ -537,27 +547,36 @@ main (int argc, char *argv[])
 				   long_options, &option_index)) != EOF) {
 		switch (opt) {
 
+		case 'c':
+			if (tolower (optarg[0]) == 'h') {
+				clock_source = JACK_TIMER_HPET;
+			} else if (tolower (optarg[0]) == 'c') {
+				clock_source = JACK_TIMER_CYCLE_COUNTER;
+			} else if (tolower (optarg[0]) == 's') {
+				clock_source = JACK_TIMER_SYSTEM_CLOCK;
+			} else {
+				usage (stderr);
+				return -1;
+			}
+			break;
+
 		case 'd':
 			seen_driver = 1;
 			driver_name = optarg;
 			break;
 
-		case 'v':
-			verbose = 1;
-			break;
-
-		case 's':
-			jack_set_error_function (silent_jack_error_callback);
-			break;
-
-		case 'n':
-			server_name = optarg;
+		case 'D':
+			frame_time_offset = JACK_MAX_FRAMES - atoi(optarg); 
 			break;
 
 		case 'm':
 			do_mlock = 0;
 			break;
 
+		case 'n':
+			server_name = optarg;
+			break;
+
 		case 'p':
 			port_max = (unsigned int) atol (optarg);
 			break;
@@ -570,6 +589,10 @@ main (int argc, char *argv[])
 			realtime = 1;
 			break;
 
+		case 's':
+			jack_set_error_function (silent_jack_error_callback);
+			break;
+
 		case 'T':
 			temporary = 1;
 			break;
@@ -582,12 +605,16 @@ main (int argc, char *argv[])
 			do_unlock = 1;
 			break;
 
+		case 'v':
+			verbose = 1;
+			break;
+
 		case 'V':
 			show_version = 1;
 			break;
 
 		default:
-			fprintf (stderr, "unknown option character %c\n",
+			fprintf (stderr, "Unknown option character %c\n",
 				 optopt);
 			/*fallthru*/
 		case 'h':
@@ -604,6 +631,12 @@ main (int argc, char *argv[])
 		return -1;
 	}
 
+	if (realtime && (client_timeout >= JACKD_WATCHDOG_TIMEOUT)) {
+		usage (stderr);
+		fprintf (stderr, "In realtime mode (-R) the client timeout must be smaller than the watchdog timeout (%ims).\n", JACKD_WATCHDOG_TIMEOUT);
+		exit (1);
+	}
+
 	if (!seen_driver) {
 		usage (stderr);
 		exit (1);
