@@ -17,7 +17,7 @@
     along with this program; if not, write to the Free Software 
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: client.c,v 1.125 2006/01/03 21:10:49 sonarnerd Exp $
+    $Id: client.c 948 2006-05-15 17:12:44Z pbd $
 */
 
 #include <config.h>
@@ -50,12 +50,12 @@
 #include <jack/intsimd.h>
 
 #include <sysdeps/time.h>
-JACK_TIME_GLOBAL_DECL;			/* One instance per process. */
 
 #include "local.h"
 
 #include <sysdeps/poll.h>
 #include <sysdeps/ipc.h>
+#include <sysdeps/cycles.h>
 
 #ifdef JACK_USE_MACH_THREADS
 #include <sysdeps/pThreadUtilities.h>
@@ -77,7 +77,6 @@ int cpu_type = 0;
 #define event_fd pollfd[EVENT_POLL_INDEX].fd
 #define graph_wait_fd pollfd[WAIT_POLL_INDEX].fd
 
-
 typedef struct {
     int status;
     struct _jack_client *client;
@@ -528,6 +527,8 @@ server_connect (const char *server_name)
 	struct sockaddr_un addr;
 	int which = 0;
 
+        char server_dir[PATH_MAX+1] = "";
+
 	if ((fd = socket (AF_UNIX, SOCK_STREAM, 0)) < 0) {
 		jack_error ("cannot create client socket (%s)",
 			    strerror (errno));
@@ -539,7 +540,7 @@ server_connect (const char *server_name)
 
 	addr.sun_family = AF_UNIX;
 	snprintf (addr.sun_path, sizeof (addr.sun_path) - 1, "%s/jack_%d",
-		  jack_server_dir (server_name), which);
+                  jack_server_dir (server_name, server_dir) , which);
 
 	if (connect (fd, (struct sockaddr *) &addr, sizeof (addr)) < 0) {
 		close (fd);
@@ -557,6 +558,8 @@ server_event_connect (jack_client_t *client, const char *server_name)
 	jack_client_connect_ack_request_t req;
 	jack_client_connect_ack_result_t res;
 
+        char server_dir[PATH_MAX+1] = "";
+
 	if ((fd = socket (AF_UNIX, SOCK_STREAM, 0)) < 0) {
 		jack_error ("cannot create client event socket (%s)",
 			    strerror (errno));
@@ -565,7 +568,7 @@ server_event_connect (jack_client_t *client, const char *server_name)
 
 	addr.sun_family = AF_UNIX;
 	snprintf (addr.sun_path, sizeof (addr.sun_path) - 1, "%s/jack_ack_0",
-		  jack_server_dir (server_name));
+		  jack_server_dir (server_name,server_dir));
 
 	if (connect (fd, (struct sockaddr *) &addr, sizeof (addr)) < 0) {
 		jack_error ("cannot connect to jack server for events",
@@ -988,6 +991,9 @@ jack_client_open (const char *client_name,
 	
 	client->engine = (jack_control_t *) jack_shm_addr (&client->engine_shm);
 
+	/* initialize clock source as early as possible */
+	jack_set_clock_source (client->engine->clock_source);
+
 	/* now attach the client control block */
 	client->control_shm = res.client_shm;
 	if (jack_attach_shm (&client->control_shm)) {
@@ -1117,7 +1123,7 @@ char *jack_tmpdir = DEFAULT_TMP_DIR;
 char *
 jack_user_dir (void)
 {
-	static char user_dir[PATH_MAX] = "";
+	static char user_dir[PATH_MAX+1] = "";
 
 	/* format the path name on the first call */
 	if (user_dir[0] == '\0') {
@@ -1130,15 +1136,13 @@ jack_user_dir (void)
 
 /* returns the name of the per-server subdirectory of jack_user_dir() */
 char *
-jack_server_dir (const char *server_name)
+jack_server_dir (const char *server_name, char *server_dir)
 {
-	static char server_dir[PATH_MAX] = "";
+	/* format the path name into the suppled server_dir char array,
+	 * assuming that server_dir is at least as large as PATH_MAX+1 */
 
-	/* format the path name on the first call */
-	if (server_dir[0] == '\0') {
-		snprintf (server_dir, sizeof (server_dir), "%s/%s",
-			  jack_user_dir (), server_name);
-	}
+	snprintf (server_dir, PATH_MAX+1, "%s/%s",
+		  jack_user_dir (), server_name);
 
 	return server_dir;
 }
