@@ -16,7 +16,7 @@
     along with this program; if not, write to the Free Software 
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: port.c,v 1.20 2006/01/03 21:10:49 sonarnerd Exp $
+    $Id: port.c 985 2006-08-29 15:21:17Z paul $
 */
 
 #include <string.h>
@@ -31,6 +31,7 @@
 #include <jack/engine.h>
 #include <jack/pool.h>
 #include <jack/port.h>
+#include <jack/midiport.h>
 #include <jack/jslist.h>
 #include <jack/intsimd.h>
 
@@ -39,6 +40,9 @@
 static void    jack_audio_port_mixdown (jack_port_t *port,
 					jack_nframes_t nframes);
 
+extern void jack_midi_port_mixdown (jack_port_t *port,
+ 					jack_nframes_t nframes);
+ 
 /* These function pointers are local to each address space.  For
  * internal clients they reside within jackd; for external clients in
  * the application process. */
@@ -46,15 +50,22 @@ jack_port_functions_t jack_builtin_audio_functions = {
 	.mixdown = jack_audio_port_mixdown, 
 };
 
+jack_port_functions_t jack_builtin_midi_functions = {
+	.mixdown = jack_midi_port_mixdown, 
+};
+
 jack_port_functions_t jack_builtin_NULL_functions = {
 	.mixdown = NULL, 
 };
 
-/* Only the Audio port type is currently built in. */
+/* Only the Audio and MIDI port types are currently built in. */
 jack_port_type_info_t jack_builtin_port_types[] = {
 	{ .type_name = JACK_DEFAULT_AUDIO_TYPE, 
 	  .buffer_scale_factor = 1,
 	},
+	{ .type_name = JACK_DEFAULT_MIDI_TYPE, 
+	  .buffer_scale_factor = 1,
+	},
 	{ .type_name = "", }
 };
 
@@ -351,6 +362,11 @@ jack_port_new (const jack_client_t *client, jack_port_id_t port_id,
 			port->fptr = jack_builtin_audio_functions;
 			port->shared->has_mixdown = TRUE;
 
+		} else if (ptid == JACK_MIDI_PORT_TYPE) {
+
+			port->fptr = jack_builtin_midi_functions;
+			port->shared->has_mixdown = TRUE;
+
 		} else {	/* no other builtin functions */
 
 			port->fptr = jack_builtin_NULL_functions;
@@ -734,7 +750,7 @@ jack_port_get_buffer (jack_port_t *port, jack_nframes_t nframes)
 				* nframes);
 	}
 	port->fptr.mixdown (port, nframes);
-	return (jack_default_audio_sample_t *) port->mix_buffer;
+	return (void *) port->mix_buffer;
 }
 
 int
@@ -832,7 +848,7 @@ jack_port_request_monitor_by_name (jack_client_t *client,
 }
 
 int
-jack_ensure_port_monitor_input (jack_port_t *port, int yn)
+jack_port_ensure_monitor (jack_port_t *port, int yn)
 {
 	if (yn) {
 		if (port->shared->monitor_requests == 0) {
@@ -964,3 +980,8 @@ jack_audio_port_mixdown (jack_port_t *port, jack_nframes_t nframes)
 #endif /* USE_DYNSIMD */
 	}
 }
+
+
+
+
+
