@@ -43,15 +43,29 @@ static inline void
 jack_read_frame_time (const jack_client_t *client, jack_frame_timer_t *copy)
 {
 	int tries = 0;
+	long timeout = 1000;
 
 	do {
 		/* throttle the busy wait if we don't get 
 		   the answer very quickly.
+
+		   XXX This is disgusting. on a UP
+		   system, it needs to sleep
+		   if the first try didn't work. on an SMP
+		   system, it should wait for half of
+		   the context switch time before
+		   sleeping.
 		*/
 
 		if (tries > 10) {
 			usleep (20);
 			tries = 0;
+
+			/* debug code to avoid system hangs... */
+			if (--timeout == 0) {
+				jack_error ("hung in loop copying position A");
+				abort();
+			}
 		}
 
 		*copy = client->engine->frame_timer;
@@ -70,14 +84,16 @@ jack_transport_copy_position (jack_position_t *from, jack_position_t *to)
 
 	do {
 		/* throttle the busy wait if we don't get the answer
-		 * very quickly. */
+		 * very quickly. See comment above about this
+		 * design.
+		 */
 		if (tries > 10) {
 			usleep (20);
 			tries = 0;
 
 			/* debug code to avoid system hangs... */
 			if (--timeout == 0) {
-				jack_error("hung in loop copying position");
+				jack_error ("hung in loop copying position B");
 				abort();
 			}
 		}
@@ -218,19 +234,30 @@ jack_frames_since_cycle_start (const jack_client_t *client)
 jack_nframes_t
 jack_frame_time (const jack_client_t *client)
 {
-	jack_frame_timer_t current;
-	float usecs;
-	jack_nframes_t elapsed;
+	jack_frame_timer_t time;
 	jack_control_t *ectl = client->engine;
 
-	jack_read_frame_time (client, &current);
-	
-	usecs = jack_get_microseconds() - current.stamp;
-	elapsed = (jack_nframes_t)
-		floor ((((float) ectl->current_time.frame_rate)
-			/ 1000000.0f) * usecs);
-	
-	return current.frames + elapsed;
+	jack_read_frame_time (client, &time);
+
+	if (time.initialized) {
+		jack_time_t now = jack_get_microseconds();
+
+#if 0
+		fprintf (stderr, "now = %Lu current wakeup = %Lu next = %Lu frames = %lu + %f => %lu\n", 
+			 now, time.current_wakeup, time.next_wakeup, time.frames,
+			 (double) (now - time.current_wakeup)/ 
+			 (time.next_wakeup - time.current_wakeup),
+			 time.frames + 
+			 (long) rint (((double) (now - time.current_wakeup)/ 
+						 (time.next_wakeup - time.current_wakeup)) * ectl->buffer_size));
+#endif		
+
+		return time.frames + 
+			(long) rint (((double) ((long long) (now - time.current_wakeup))/ 
+						((long long) (time.next_wakeup - time.current_wakeup))) * ectl->buffer_size);
+	} 
+
+	return 0;
 }
 
 jack_nframes_t
