@@ -16,7 +16,7 @@
     along with this program; if not, write to the Free Software 
     Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
-    $Id: unlock.c,v 1.2 2005/03/20 18:03:09 pbd Exp $
+    $Id: unlock.c 945 2006-05-04 15:14:45Z pbd $
 */
 
 #include <stdio.h>
@@ -37,6 +37,7 @@ static char* blacklist[] = {
 
 static char* whitelist[] = {
 	"/libc-",
+	"/libardour",
 	NULL
 };
 
@@ -73,7 +74,7 @@ cleanup_mlock ()
 
 		unlock = 0;
 
-		if (fscanf (map, "%x-%x %*s %*x %*d:%*d %d",
+		if (fscanf (map, "%zx-%zx %*s %*x %*d:%*d %d",
 			    &start, &end, &whoknows) != 3) {
 			break;
 		}
